<?php
/*
	Plugin Name: PRO Player
	Plugin URI: http://isagoksu.com/projects
	Description: Display online videos from various sources in any Custom FLV Player. For details please visit <a href="http://isagoksu.com/projects" target="_new">project page</a> for more information. 
	Author: Isa Goksu
	Version: 1.5
	Author URI: http://isagoksu.com

	Copyright (c) 2009, Isa Goksu [ info@isagoksu.com ]

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	Special thanks to:
	- Chaosmaster who prepared some of the functions for generating FLV files from various sources.
	- SWFObject [ http://code.google.com/p/swfobject ] authors, they made flash part really easier.
*/

require dirname(__FILE__) . "/flv-generator.php";

if (!class_exists("ProPlayer")) {
	class ProPlayer {
		var $PLAYER_CODE_PATTERN = "/\[pro\-player(.+)pro\-player\]/i";
		var $VIDEO_URL_PATTERN = "/\](.*)\[/i";
		var $WIDTH_PATTERN = "/width\s*=\s*([\"\'])\s*\d+\s*([\"\'])/i";
		var $HEIGHT_PATTERN = "/height\s*=\s*([\"\'])\s*\d+\s*([\"\'])/i";
		var $TYPE_PATTERN = "/type\s*=\s*([\"\'])\s*\w+\s*([\"\'])/i";
		var $SUPPORTED_SOURCES = array("youtube.com", "tudou.com", "veoh.com", "56.com", "dailymotion.com", "myvideo.de", "ebaumsworld.com", "clipfish.de", "crunchyroll.com", "bofunk.com", "google.com", "metacafe.com", "bebo.com", "myspace.com", "vimeo.com", "supernovatube.com", "youku.com");
		var $SUPPORTED_AUDIO_FILES = array("mp3", "rbs");
		var $PLUGIN_URL;
		var $PLAYER_URL;
		
		var $error = "";

		var $name;
		var $width;
		var $height;
		var $type;
		
		//constructor
		function ProPlayer() { 
			// default attributes
			$this->width = get_option("PRO_PLAYER_WIDTH");
			$this->height = get_option("PRO_PLAYER_HEIGHT");
			$this->type = get_option("PRO_PLAYER_TYPE");
			
			$this->PLUGIN_URL = WP_PLUGIN_URL."/proplayer";
			$this->PLAYER_URL = $this->PLUGIN_URL."/players";
		}
		
		function buildPlayer($match = '') {
			global $wp_query;
			// $this->versionCheck();
			
			if (empty($this->error)) {
				preg_match($this->VIDEO_URL_PATTERN, $match, $urlMatch);
				$videoURL = trim($urlMatch[1], " ");
				// $this->contentCheck($videoURL);
				
				if (empty($this->error)) {
					if ($this->contains($videoURL)) {
						// get the online video source link
						$url = getLink($videoURL, $this->type);
					} else {
						$url = $videoURL;
					}					

					if ($this->isValidURL($url)) {
						$id = $wp_query->post->ID;
						$title = $wp_query->post->post_title;
						$plugins = "";
						
						if (empty($this->type)) {
							$this->type = get_option("PRO_PLAYER_TYPE");
						}

						if (get_option("PRO_PLAYER_VISUALIZER_SUPPORT") == "true" && in_array(strtolower($this->type), $this->SUPPORTED_AUDIO_FILES)) {
							$plugins .= "revolt-1,";
						}
						
						if (get_option("PRO_PLAYER_RATING_SUPPORT") == "true") {
							$plugins .= "rateit-1,";
						}
						
						$watermark = "";
						if (get_option("PRO_PLAYER_SHOW_WATERMARK") == "true") {
							$watermark = "logo: '".$this->getWatermark()."',";
						}
						
						return "
						  <!-- ProPlayer by Isa Goksu -->
							<div class=\"pro-player-container\" width=\"".$this->width."px\" height=\"".$this->height."px\"><div id=\"pro-player-".$wp_query->post->ID."\"></div></div>
							<script type=\"text/javascript\" charset=\"utf-8\">
									var flashvars = {
										file: '".urlencode($url)."',
										backcolor: '".get_option("PRO_PLAYER_BACKCOLOR")."',
										frontcolor: '".get_option("PRO_PLAYER_FRONTCOLOR")."',
										lightcolor: '".get_option("PRO_PLAYER_LIGHTCOLOR")."',
										skin: '".get_option("PRO_PLAYER_SKIN_FILE")."',
										stretching: '".get_option("PRO_PLAYER_STRETCHING")."',
										title: '".$title."',
										plugins: '".$plugins."',
										".$watermark."
										type: '".$this->type."'
									};
									
									var params = {
										wmode: 'opaque',
										allowfullscreen: 'true',
										allowscriptaccess: 'always'
									};

									var attributes = {
										id: 'obj-pro-player-".$id."',
										name: 'obj-pro-player-".$id."'
									};
									
									swfobject.embedSWF('".$this->getPlayer()."', 'pro-player-".$id."', '".$this->width."', '".$this->height."', '9.0.0', false, flashvars, params, attributes);
							</script>
						";
					} else {
						return "<h3>This video is not available at the moment, please try again later!</h3>\n";						
					}
				}
			}
			
			return $this->error;
		}
		
		function setAttributes($match = '') {
			// for width
			preg_match($this->WIDTH_PATTERN, $match, $widthMatch);

			if (!empty($widthMatch[0])) {
				$this->width = preg_replace("(width=)", "", preg_replace("/[\ \'\"]*/", "", $widthMatch[0]));
			}

			// for height
			preg_match($this->HEIGHT_PATTERN, $match, $heightMatch);

			if (!empty($heightMatch[0])) {
				$this->height = preg_replace("(height=)", "", preg_replace("/[\ \'\"]*/", "", $heightMatch[0]));
			}

			// for type
			preg_match($this->TYPE_PATTERN, $match, $typeMatch);

			if (!empty($typeMatch[0])) {
				$this->type = preg_replace("(type=)", "", preg_replace("/[\ \'\"]*/", "", $typeMatch[0]));
			}

		}
		
		/* Wordpress Settings */
		
		function addHeaderCode() {
			print "<script type='text/javascript' src='".$this->PLUGIN_URL."/js/swfobject.js'></script>";
		}
		
		function addPlayerCode($content = '') {
			preg_match($this->PLAYER_CODE_PATTERN, trim($content), $matches);
			$this->setAttributes($matches[0]);
			
			return preg_replace($this->PLAYER_CODE_PATTERN, $this->buildPlayer($matches[0]), $content);
		}
		
		function addOptions() {
			add_option("PRO_PLAYER_WIDTH", "530");
			add_option("PRO_PLAYER_HEIGHT", "253");
			add_option("PRO_PLAYER_TYPE", "FLV");
			add_option("PRO_PLAYER_BACKCOLOR", "111111");
			add_option("PRO_PLAYER_FRONTCOLOR", "cccccc");
			add_option("PRO_PLAYER_LIGHTCOLOR", "66cc00");
			add_option("PRO_PLAYER_STRETCHING", "fill");
			add_option("PRO_PLAYER_SKIN_FILE", $this->getPlayerStyle());
			add_option("PRO_PLAYER_VISUALIZER_SUPPORT", "true");
			add_option("PRO_PLAYER_RATING_SUPPORT", "true");
			add_option("PRO_PLAYER_SHOW_WATERMARK", "true");
		}

		function removeOptions() {
			delete_option("PRO_PLAYER_WIDTH");
			delete_option("PRO_PLAYER_HEIGHT");
			delete_option("PRO_PLAYER_TYPE");
			delete_option("PRO_PLAYER_BACKCOLOR");
			delete_option("PRO_PLAYER_FRONTCOLOR");
			delete_option("PRO_PLAYER_LIGHTCOLOR");
			delete_option("PRO_PLAYER_STRETCHING");
			delete_option("PRO_PLAYER_SKIN_FILE");
			delete_option("PRO_PLAYER_VISUALIZER_SUPPORT");
			delete_option("PRO_PLAYER_RATING_SUPPORT");
			delete_option("PRO_PLAYER_SHOW_WATERMARK");
		}
		
		function addOptionsPage() {
			add_options_page(
				"ProPlayer Configuration",
				"ProPlayer",
				9,
				"proplayer/options-page.php"
			);	
		}
		
		function updateOptions($post) {
			if (is_array($post)) {
				update_option("PRO_PLAYER_WIDTH", $post["proPlayerWidth"]);
				update_option("PRO_PLAYER_HEIGHT", $post["proPlayerHeight"]);
				update_option("PRO_PLAYER_TYPE", $post["proPlayerType"]);
				update_option("PRO_PLAYER_BACKCOLOR", $post["proPlayerBackColor"]);
				update_option("PRO_PLAYER_FRONTCOLOR", $post["proPlayerFrontColor"]);
				update_option("PRO_PLAYER_LIGHTCOLOR", $post["proPlayerLightColor"]);
				update_option("PRO_PLAYER_STRETCHING", $post["proPlayerStretching"]);
				update_option("PRO_PLAYER_SKIN_FILE", $post["proPlayerSkinFile"]);
				update_option("PRO_PLAYER_VISUALIZER_SUPPORT", isset($post["proPlayerVisualizerSupport"]) ? $post["proPlayerVisualizerSupport"] : "false");
				update_option("PRO_PLAYER_RATING_SUPPORT", isset($post["proPlayerRatingSupport"]) ? $post["proPlayerRatingSupport"] : "false");
				update_option("PRO_PLAYER_SHOW_WATERMARK", isset($post["proPlayerShowWatermark"]) ? $post["proPlayerShowWatermark"] : "false");
			}
		}
		
		/* Utility Functions */
		
		function contains($url = '') {
			if (!empty($url)) {
				foreach ($this->SUPPORTED_SOURCES as $source) {
					if (strstr($url, $source)) {
						return true;
					}
				}
			}
			
			return false;
		}
		
		function getPlayer() {
			// define your custom player swf file here
			return $this->PLAYER_URL."/player.swf";
		}
		
		function getWatermark() {
			return $this->PLAYER_URL."/watermark.png";
		}
	
		function getPlayerStyle() {
			// define your custom skin file here - this method is only valid for JW FLV Media Player
			return $this->getSkinPath()."/default.swf";
		}
		
		function getSkinPath() {
			return $this->PLAYER_URL."/skins";
		}
		
		/* Error Check */
		
		function contentCheck($content = '') {
			if (empty($content)) {
				$this->error = "<h3>You need to put some VIDEO URL here!</h3>\n";
			}
		}

		function isValidURL($url = '') {
			return strstr($url, "http");
		}

	}
}

$proPlayer = new ProPlayer();

// add plugin actions
add_action("wp_head", array(&$proPlayer, "addHeaderCode"), 1);
add_filter("the_content", array(&$proPlayer, "addPlayerCode")); 

// register option hooks
register_activation_hook(__FILE__, array(&$proPlayer, "addOptions"));
register_deactivation_hook(__FILE__, array(&$proPlayer, "removeOptions"));

// add options page
add_action("admin_menu", array(&$proPlayer, "addOptionsPage"));

?>
